<p align="center">
    <a href="https://github.com/durandtibo/gravitorch/actions">
        <img alt="CI" src="https://github.com/durandtibo/gravitorch/workflows/CI/badge.svg">
    </a>
    <a href="https://durandtibo.github.io/gravitorch/">
        <img alt="Documentation" src="https://github.com/durandtibo/gravitorch/workflows/Documentation/badge.svg">
    </a>
    <a href="https://github.com/durandtibo/gravitorch/actions">
        <img alt="Nightly Tests" src="https://github.com/durandtibo/gravitorch/workflows/Nightly%20Tests/badge.svg">
    </a>
    <a href="https://github.com/durandtibo/gravitorch/actions">
        <img alt="Nightly Package Tests" src="https://github.com/durandtibo/gravitorch/workflows/Nightly%20Package%20Tests/badge.svg">
    </a>
    <br/>
    <a href="https://codecov.io/gh/durandtibo/gravitorch">
        <img alt="Codecov" src="https://codecov.io/gh/durandtibo/gravitorch/branch/main/graph/badge.svg">
    </a>
    <a href="https://codeclimate.com/github/durandtibo/gravitorch/maintainability">
        <img src="https://api.codeclimate.com/v1/badges/cbedbd2a20bf2a21cf22/maintainability" />
    </a>
    <a href="https://codeclimate.com/github/durandtibo/gravitorch/test_coverage">
        <img src="https://api.codeclimate.com/v1/badges/cbedbd2a20bf2a21cf22/test_coverage" />
    </a>
    <br/>
    <a href="https://pypi.org/project/gravitorch/">
        <img alt="PYPI version" src="https://img.shields.io/pypi/v/gravitorch">
    </a>
    <a href="https://pypi.org/project/gravitorch/">
        <img alt="Python" src="https://img.shields.io/pypi/pyversions/gravitorch.svg">
    </a>
    <a href="https://opensource.org/licenses/BSD-3-Clause">
        <img alt="BSD-3-Clause" src="https://img.shields.io/pypi/l/gravitorch">
    </a>
    <a href="https://github.com/psf/black">
        <img  alt="Code style: black" src="https://img.shields.io/badge/code%20style-black-000000.svg">
    </a>
    <a href="https://google.github.io/styleguide/pyguide.html#s3.8-comments-and-docstrings">
        <img  alt="Doc style: google" src="https://img.shields.io/badge/%20style-google-3666d6.svg">
    </a>
    <br/>
    <a href="https://pepy.tech/project/gravitorch">
        <img  alt="Downloads" src="https://static.pepy.tech/badge/gravitorch">
    </a>
    <a href="https://pepy.tech/project/gravitorch">
        <img  alt="Monthly downloads" src="https://static.pepy.tech/badge/gravitorch/month">
    </a>
    <br/>
</p>

## API stability

:warning: While `gravitorch` is in development stage, no API is guaranteed to be stable from one
release to the next. In fact, it is very likely that the API will change multiple times before a
stable 1.0.0 release. In practice, this means that upgrading `gravitorch` to a new version will
possibly break any code that was using the old version of `gravitorch`.

## License

`gravitorch` is licensed under BSD 3-Clause "New" or "Revised" license available
in [LICENSE](LICENSE) file.
